@@ -54,7 +54,7 @@ typedef struct {
  /* Global variable */
 /*******************/
 
-Display		*display;
+extern Display	*display;
 
   /***********************/
  /* Function Prototypes */
